@@ -10,13 +10,13 @@ use Test::Assert ':all';
 
 sub test_api {
     my @api = grep { ! /^_/ } @{ Class::Inspector->functions('Test::Mock::Class::Role::Meta::Class') };
-    assert_deep_equals( [ qw{
+    assert_deep_equals( [ qw(
         add_mock_constructor
         add_mock_method
         create_mock_anon_class
         create_mock_class
         meta
-    } ], \@api );
+    ) ], \@api );
 };
 
 1;
